@@ -6,31 +6,26 @@ use overload
     '""' => sub { $_[0]->to_string || $_[0] };
 
 use Class::Accessor::Lite (
-    ro => [qw/ delivery is_delivery_duplicated duplicated_trace /],
+    ro => [qw/ delivery /],
 );
-use Time::Piece qw(localtime);
-use Time::HiRes qw(gettimeofday tv_interval);
 use Data::Dumper;
 use Data::Util qw(is_instance);
 
-our $VERSION   = "0.10";
+our $VERSION   = "0.11";
 our $SkipDepth = 0;
 
-# class method
 sub new {
     my ($class, %args) = @_;
 
     my $self = bless {
-        tags                   => {},
-        stack                  => [],
-        message                => undef,
-        delivery               => undef,
-        is_delivery_duplicated => 0,
-        duplicated_trace       => [],
+        tags     => {},
+        stack    => [],
+        message  => undef,
+        delivery => undef,
     }, $class;
 }
 
-sub _get_external_caller {
+sub _target_caller {
     my $class = shift;
     my $i = 0;
     while (my @caller = caller(++$i)) {
@@ -85,8 +80,6 @@ sub dumper {
     return $value;
 }
 
-# instance method
-
 sub throw {
     my ($class, @args) = @_;
     my $builded_args = $class->_build_arg(@args);
@@ -138,7 +131,7 @@ sub add_message {
 sub logging {
     my ($self, $args) = @_;
 
-    my ($pkg, $file, $line) = $self->_get_external_caller;
+    my ($pkg, $file, $line) = $self->_target_caller;
 
     if (%{$args}) {
         if (my $tags = $args->{tag}) {
@@ -151,16 +144,7 @@ sub logging {
             push @{$self->{stack}}, "$message at $file line $line.";
         }
         if (my $delivery = $args->{delivery}) {
-            if ($self->delivery) {
-                unless ($self->is_delivery_duplicated) {
-                    $self->{is_delivery_duplicated} = 1;
-                    push @{$self->{duplicated_trace}}, $self->{stack}->[0];
-                }
-                push @{$self->{duplicated_trace}}, "$file line $line." ;
-            }
-            else {
-                $self->{delivery} = $delivery;
-            }
+            $self->{delivery} = $delivery;
         }
     }
     else {
@@ -246,7 +230,7 @@ store a following value.
 
 =item message ($info{message})
 
-=item delivery ($info{delivery}). it's stored only once.
+=item delivery ($info{delivery})
 
 =back
 
@@ -290,16 +274,6 @@ matching stored tag.
 
 delivered object. (or scalar object)
 
-=head2 is_delivery_duplicated
-
-(it's development tool)
-if delivery was duplicated, 1;
-
-=head2 duplicated_trace
-
-(it's development tool)
-description of the occured file and line.
-
 =head1 GLOBAL VARIABLES
 
 $Exception::Chain::SkipDepth
